<?php

namespace Modules\Atendimento\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\Report\ReportService;
use Modules\Atendimento\Services\Gql00800OService;
use Zeedhi\Framework\DataSource\DataSet;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DataSource\FilterCriteria;

class Gql00800Controller extends \Teknisa\GER\Controllers\TeknisaCrud
{
    protected $dataSourceName = "gql00800_grid_data";
    protected $crudService;
    protected $parameterBag;
    protected $connection;
    protected $entityManager;
    protected $environment;
    protected $fileServerPath;

    public function __construct($crudService, $parameterBag, Gql00800OService $service, $connection, $entityManager, $environment, $fileServerPath)
    {
        $this->crudService    = $crudService;
        $this->parameterBag   = $parameterBag;
        $this->service        = $service;
        $this->connection     = $connection;
        $this->entityManager  = $entityManager;
        $this->environment    = $environment;
        $this->fileServerPath = $fileServerPath;
    }

    public function filterGridData(DTO\Request\Filter $request, DTO\Response $response)
    {
        $this->datasourceName = "gql00800_grid_data";
        $filterCriteria = $request->getFilterCriteria();
        $conditions = $filterCriteria->getConditions();
		$filterCriteria->addCondition("CDOPERADOR", $this->environment->getCdoperador());
		parent::find($request, $response);
    }

    public function salvarDadosOcorrencia(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();

        $widgetRow = $row["widgetRow"];
        if (isset($widgetRow['__is_new']) && $widgetRow['__is_new']) {
            $DATA = $this->service->insertData($widgetRow);
        } else {
            $DATA = $this->service->updateData($widgetRow);
        }

        $response->addDataSet(new DataSet('DATA', $DATA));
    }

    public function salvarDescricao(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        $query = "SELECT * FROM DESCMOVOCORR WHERE NROCORRMOV = {$row['NROCORRMOV']} AND CDFILILANCMO = {$row['CDFILILANCMO']}";

        $std = $this->connection->prepare($query);
        $std->execute();
        $descricao = $std->fetch();

        if ($descricao) {
            $this->service->updateDescription($row['DESCRICAO'], $row['CDFILILANCMO'], $row['NROCORRMOV']);
        } else {
            $this->service->insertDescription($row['DESCRICAO'], $row['CDFILILANCMO'], $row['NROCORRMOV']);
        }
    }

    public function salvarParecer(DTO\Request\Row $request)
    {

        $row = $request->getRow();

        $query = "SELECT CDFILILANCMO FROM PARECER WHERE NROCORRMOV = {$row['NROCORRMOV']} AND CDFILILANCMO = {$row['CDFILILANCMO']}";

        $std = $this->connection->prepare($query);

        $std->execute();

        $parecer = $std->fetch();

        if ($parecer) {

            $this->service->updateParecer($row['PARECER'], $row['CDFILILANCMO'], $row['NROCORRMOV']);
        } else {

            $this->service->insertParecer($row['PARECER'], $row['CDFILILANCMO'], $row['NROCORRMOV']);
        }
    }

    public function imageSave(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();


        $query = "SELECT CDFILILANCMO FROM FOTOMOVOCORR WHERE NROCORRMOV = {$row['NROCORRMOV']} AND CDFILILANCMO = {$row['CDFILILANCMO']}";

        $std = $this->connection->prepare($query);

        $std->execute();

        $image = $std->fetch();

        $CDFILILANCMO = $row["CDFILILANCMO"] ?? null;
        $NROCORRMOV = $row["NROCORRMOV"] ?? null;
        $DSFOTOOCORR = $row['IMAGE'][0]['path'] ?? null;

        try {
            if ($image) {
                $this->service->updateFoto($DSFOTOOCORR, $CDFILILANCMO, $NROCORRMOV);
            } else {

                $this->service->insertFoto($DSFOTOOCORR, $CDFILILANCMO, $NROCORRMOV);
            }

            if ($DSFOTOOCORR) {
                $DSFOTOOCORR = $this->fileServerPath . $DSFOTOOCORR;
            }
            $response->addDataSet(new DataSet('fotopath', [$DSFOTOOCORR]));
        } catch (\Exception $e) {
            $response->setError(new Error("UPLOADERROR", 1));
        }
    }

    public function findImage(DTO\Request\Filter $filter, DTO\Response $response)
    {
        $datasourceName = "fotomovocorr";

        $oldFilterCriteria = $filter->getFilterCriteria();

        $filters = $oldFilterCriteria->getConditions();

        $page = $oldFilterCriteria->getPage();
        $pageSize = $oldFilterCriteria->getPageSize();

        $filterCriteria = new FilterCriteria($datasourceName, $filters, $page, $pageSize);

        $this->crudService->find($response, $filterCriteria);

        $dataSet = $response->getDataSets()[0];

        $rows = $dataSet->getRows();

        foreach ($rows as &$row) {
            $row["DSFOTOOCORR"] = $row["DSFOTOOCORR"] === null ? null : $this->fileServerPath . $row["DSFOTOOCORR"];
        }

        $response->setDataSets([new DataSet($datasourceName, $rows)]);
    }

    public function saveCollectedData(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $this->service->saveCollectedData($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
}
