<?php

namespace OrcamentoOperacional\Logic\Exceptions;

/**
 *
 */
class Orcamento extends \OrcamentoOperacional\Logic\Exception
{

    private $messageName;

    /**
     * Construtor.
     *
     * Recebe o nome da mensagem cadastrada no setforms.
     *
     * @param string $messageName
     * @param string $message
     * @param int $code
     * @param \Exception|null $previous
     */
    public function __construct($messageName, $message = "", $code = 0, \Exception $previous = null)
    {
        parent::__construct($message, $code, $previous);
        $this->messageName = $messageName;
    }


    /**
     * Retorna o nome da mensagem cadastrada no Setforms para esta excecao.
     *
     * @return string
     */
    public function getMessageName()
    {
        return $this->messageName;
    }

    /**
     * ORC1.
     * Excecao para os casos em que o valor da despesa de entrada superou o valor de consumo orcado.
     *
     * @static
     * @return string
     */
    public static function valorDeEntradaSuperouValorDeConsumoOrcado()
    {
        throw new self (
            "msg_tecfood_orc1",
            "O lançamento será bloqueado porque o valor das entradas é maior que o valor do consumo orçado."
        );
    }

    /**
     * ORC2.
     * Excecao para os casos em que o valor da despesa de entrada superou o valor da despesa orcada.
     *
     * @static
     * @return string
     */
    public static function valorDeEntradaSuperouValorDeDespesasOrcadas()
    {
        throw new self (
            "msg_tecfood_orc2",
            "O lançamento será bloqueado porque porque o valor das entradas superou o valor das despesas de".
            "entrada orçadas."
        );
    }

    /**
     * ORC3.
     * Excecao para os casos em que o valor de alerta (parametrizado em paramfilial) foi superado pelo valor de entrada.
     * Significa que o valor de entrada ja esta proximo do limite do valor orcado.
     *
     * @static
     * @return string
     */
    public static function valorDeEntradaProximoAoValorDeConsumoOrcado()
    {
        throw new self("msg_tecfood_orc3", "O valor total de entradas já está próximo ao valor orçado de consumo.");
    }

    /**
     * ORC4.
     * Excecao para os casos em que o valor de alerta (parametrizado em paramfilial) foi superado pelo valor de despesas
     * de entrada.
     *
     * @static
     * @return string
     */
    public static function valorDeEntradaProximoAoValorDeDespesasOrcadas()
    {
        throw new self(
            "msg_tecfood_orc4",
            "O valor total de entradas já está próximo de atingir o valor orçado de despesas de entrada"
        );
    }

}
